==> ilias-4.2.5.tbz: www/ilias/Modules/Test/classes/tables/class.ilAssessmentFolderLogAdministrationTableGUI.php <==
<?php
/*
        +-----------------------------------------------------------------------------+
        | ILIAS open source                                                           |
        +-----------------------------------------------------------------------------+
        | Copyright (c) 1998-2006 ILIAS open source, University of Cologne            |
        |                                                                             |
        | This program is free software; you can redistribute it and/or               |
        | modify it under the terms of the GNU General Public License                 |
        | as published by the Free Software Foundation; either version 2              |
        | of the License, or (at your option) any later version.                      |
        |                                                                             |
        | This program is distributed in the hope that it will be useful,             |
        | but WITHOUT ANY WARRANTY; without even the implied warranty of              |
        | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
        | GNU General Public License for more details.                                |
        |                                                                             |
        | You should have received a copy of the GNU General Public License           |
        | along with this program; if not, write to the Free Software                 |
        | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
        +-----------------------------------------------------------------------------+
*/

include_once('./Services/Table/classes/class.ilTable2GUI.php');

/**
*
* @author Helmut Schottmüller <ilias@aurealis.de>
* @version $Id: class.ilAssessmentFolderLogAdministrationTableGUI.php 21454 2009-09-03 17:46:50Z hschottm $
*
* @ingroup ModulesTest
*/

class ilAssessmentFolderLogAdministrationTableGUI extends ilTable2GUI
{
	/**
	 * Constructor
	 *
	 * @access public
	 * @param
	 * @return
	 */
	public function __construct($a_parent_obj, $a_parent_cmd, $a_write_access = false)
	{
		parent::__construct($a_parent_obj, $a_parent_cmd);

		global $lng, $ilCtrl;

		$this->lng = $lng;
		$this->ctrl = $ilCtrl;
		$this->counter = 1;
		
		$this->setFormName('showlog');
		$this->setStyle('table', 'fullwidth');

		$this->addColumn('','f','1%');
		$this->addColumn($this->lng->txt("title"),'title', '');
		$this->addColumn($this->lng->txt("ass_log_count_datasets"),'nr', '');
	
		$this->setRowTemplate("tpl.il_as_tst_assessment_log_administration_row.html", "Modules/Test");

		$this->setFormAction($this->ctrl->getFormAction($a_parent_obj, $a_parent_cmd));

		if ($a_write_access)
		{
			$this->addMultiCommand('deleteLog', $this->lng->txt('ass_log_delete_entries'));
			$this->setSelectAllCheckbox('chb_test');
			$this->enable('select_all');
		}

		$this->numericOrdering('nr');
		$this->setDefaultOrderField("title");
		$this->setDefaultOrderDirection("asc");
		
		$this->setPrefix('chb_test');
		
		$this->enable('header');
		$this->enable('sort');
	}

	/**
	 * fill row 
	 *
	 * @access public
	 * @param
	 * @return
	 */
	public function fillRow($data)
	{
		$this->tpl->setVariable("TITLE", ilUtil::prepareFormOutput($data['title']));
		$this->tpl->setVariable("NR", $data['nr']);
		$this->tpl->setVariable("TEST_ID", $data['id']);
	}
}
?>

==> ilias-4.3.2.tbz: www/ilias/Modules/Test/classes/tables/class.ilAssessmentFolderLogAdministrationTableGUI.php <==
<?php
/*
        +-----------------------------------------------------------------------------+
        | ILIAS open source                                                           |
        +-----------------------------------------------------------------------------+
        | Copyright (c) 1998-2006 ILIAS open source, University of Cologne            |
        |                                                                             |
        | This program is free software; you can redistribute it and/or               |
        | modify it under the terms of the GNU General Public License                 |
        | as published by the Free Software Foundation; either version 2              |
        | of the License, or (at your option) any later version.                      |
        |                                                                             |
        | This program is distributed in the hope that it will be useful,             |
        | but WITHOUT ANY WARRANTY; without even the implied warranty of              |
        | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
        | GNU General Public License for more details.                                |
        |                                                                             |
        | You should have received a copy of the GNU General Public License           |
        | along with this program; if not, write to the Free Software                 |
        | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
        +-----------------------------------------------------------------------------+
*/

include_once('./Services/Table/classes/class.ilTable2GUI.php');

/**
*
* @author Helmut Schottmüller <ilias@aurealis.de>
* @version $Id: class.ilAssessmentFolderLogAdministrationTableGUI.php 33293 2012-02-22 11:16:43Z bheyser $
*
* @ingroup ModulesTest
*/

class ilAssessmentFolderLogAdministrationTableGUI extends ilTable2GUI
{
	/**
	 * Constructor
	 *
	 * @access public
	 * @param
	 * @return
	 */
	public function __construct($a_parent_obj, $a_parent_cmd, $a_write_access = false)
	{
		parent::__construct($a_parent_obj, $a_parent_cmd);

		global $lng, $ilCtrl;

		$this->lng = $lng;
		$this->ctrl = $ilCtrl;
		$this->counter = 1;
		
		$this->setFormName('showlog');
		$this->setStyle('table', 'fullwidth');

		$this->addColumn('','','1%', true);
		$this->addColumn($this->lng->txt("title"),'title', '');
		$this->addColumn($this->lng->txt("ass_log_count_datasets"),'nr', '');
	
		$this->setRowTemplate("tpl.il_as_tst_assessment_log_administration_row.html", "Modules/Test");

		$this->setFormAction($this->ctrl->getFormAction($a_parent_obj, $a_parent_cmd));

		if ($a_write_access)
		{
			$this->addMultiCommand('deleteLog', $this->lng->txt('ass_log_delete_entries'));
			$this->setSelectAllCheckbox('chb_test');
			$this->enable('select_all');
		}

		$this->numericOrdering('nr');
		$this->setDefaultOrderField("title");
		$this->setDefaultOrderDirection("asc");
		
		$this->setPrefix('chb_test');
		
		$this->enable('header');
		$this->enable('sort');
	}

	/**
	 * fill row 
	 *
	 * @access public
	 * @param
	 * @return
	 */
	public function fillRow($data)
	{
		$this->tpl->setVariable("TITLE", ilUtil::prepareFormOutput($data['title']));
		$this->tpl->setVariable("NR", $data['nr']);
		$this->tpl->setVariable("TEST_ID", $data['id']);
	}
}
?>
